@@ -27,9 +27,9 @@ import tensorflow as tf
 from tensorflow.python.framework import ops
 from tensorflow.python.ops import clustering_ops
 from tensorflow.python.ops import control_flow_ops
-from tensorflow.python.util.tf_export import estimator_export
 from tensorflow_estimator.python.estimator import estimator
 from tensorflow_estimator.python.estimator import model_fn as model_fn_lib
+from tensorflow_estimator.python.estimator.estimator_export import estimator_export
 from tensorflow_estimator.python.estimator.export import export_output
 
 
